@@ -534,7 +534,9 @@ def createExecutables():
     with open(digicertFilePath, 'r') as file:
         data = file.read().replace('\n', '')
     printNicely(data+"digicert key", True)
-    sedEquiv(bldCMD+CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath ])
+    changeDigicertKey=[CONST.DIGICERT_KEY, data]
+	
+    sedEquiv(bldCMD+CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath,changeDigicertKey])
     mycmd.runCommandWithArgs([bldCMD, versionNumber,Non_Bruteforce_Agent,data,">>", logFileName])
     #if retval != 0 :
         #printNicely("Error in creating the exe file. please check console output to see error", False)
@@ -710,8 +712,13 @@ def signSFX(patchDir):
     logFileName=logPath + CONST.LOG_FILE_NAME + tsToUse + CONST.LOG_FILE_EXT
     changeSignToolPath=[CONST.WIN_SIGN_TOOL_PATH_PAT, Config.get(CONST.SECTION_ASSEMBLE_PATCH, CONST.SRC_DIR)]
     changeWinInstallerPath=[CONST.WIN_INST_PATH_PAT, patchDir]
+    digicertFilePath=Config.get(CONST.SECTION_ASSEMBLE_PATCH, CONST.BASE_DIR)+"\\DigiCert\\DigicertKey.txt"
+    with open(digicertFilePath, 'r') as file:
+        data = file.read().replace('\n', '')
+    printNicely(data+"digicert key", True)
+    changeDigicertKey=[CONST.DIGICERT_KEY, data]
     # we first create the bldCMD bat file by updating the template file
-    sedEquiv(bldCMD+ CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath])
+    sedEquiv(bldCMD+ CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath,changeDigicertKey])
     mycmd.runCommandWithArgs([bldCMD, versionNumber, CONST.REDIR ,logFileName ])
 
 
